@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Games::Dice;
 # ABSTRACT: Perl module to simulate die rolls
-$Games::Dice::VERSION = '0.044';
+$Games::Dice::VERSION = '0.045';
 require Exporter;
 
 our @ISA = qw(Exporter);
@@ -30,6 +30,8 @@ sub roll ($) {
                       \d+       # either one or more digits
                     |           # or
                       %         # a percent sign for d% = d100
+                    |           # pr
+                      F         # a F for a fudge dice
                    )
                  )
                  (?:            # grouping-only parens
@@ -84,17 +86,25 @@ sub roll_array ($) {
                     \d+ # either one or more digits
                   |     # or
                     %   # a percent sign for d% = d100
+                  |     # pr
+                    F   # a F for a fudge dice
                  )
               }x;       # whitespace allowed
 
     $num    = $1 || 1;
     $type   = $2;
 
-    $type  = 100 if $type eq '%';
+    my $throw = sub { int (rand $_[0]) + 1 };
+
+    if ( $type eq '%' ) {
+        $type = 100;
+    } elsif ( $type eq 'F' ) {
+        $throw = sub { int( rand 3 ) - 1 };
+    }
 
     @throws = ();
     for( 1 .. $num ) {
-        push @throws, int (rand $type) + 1;
+        push @throws, $throw->($type);
     }
 
     return @throws;
@@ -112,7 +122,7 @@ Games::Dice - Perl module to simulate die rolls
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSIS
 
@@ -135,8 +145,9 @@ familiar to players of popular role-playing games: I<a>dI<b>[+-*/b]I<c>.
 I<a> is optional and defaults to 1; it gives the number of dice to roll.
 I<b> indicates the number of sides to each die; the most common,
 cube-shaped die is thus a d6. % can be used instead of 100 for I<b>;
-hence, rolling 2d% and 2d100 is equivalent. C<roll> simulates I<a> rolls
-of I<b>-sided dice and adds together the results. The optional end,
+hence, rolling 2d% and 2d100 is equivalent. If F is used for I<b> fudge
+dice are used, which either results in -1, 0 or 1. C<roll> simulates I<a>
+rolls of I<b>-sided dice and adds together the results. The optional end,
 consisting of one of +-*/b and a number I<c>, can modify the sum of the
 individual dice. +-*/ are similar in that they take the sum of the rolls
 and add or subtract I<c>, or multiply or divide the sum by I<c>. (x can
@@ -178,6 +189,22 @@ Ricardo Signes <rjbs@cpan.org>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords Mario Domgoergen Mark Allen
+
+=over 4
+
+=item *
+
+Mario Domgoergen <mdom@taz.de>
+
+=item *
+
+Mark Allen <mrallen1@yahoo.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 1999 by Philip Newton.
@@ -214,8 +241,9 @@ __END__
 #pod I<a> is optional and defaults to 1; it gives the number of dice to roll.
 #pod I<b> indicates the number of sides to each die; the most common,
 #pod cube-shaped die is thus a d6. % can be used instead of 100 for I<b>;
-#pod hence, rolling 2d% and 2d100 is equivalent. C<roll> simulates I<a> rolls
-#pod of I<b>-sided dice and adds together the results. The optional end,
+#pod hence, rolling 2d% and 2d100 is equivalent. If F is used for I<b> fudge
+#pod dice are used, which either results in -1, 0 or 1. C<roll> simulates I<a>
+#pod rolls of I<b>-sided dice and adds together the results. The optional end,
 #pod consisting of one of +-*/b and a number I<c>, can modify the sum of the
 #pod individual dice. +-*/ are similar in that they take the sum of the rolls
 #pod and add or subtract I<c>, or multiply or divide the sum by I<c>. (x can
